"""
pytest local configuration plug-in
"""

from __future__ import annotations

import os.path
import subprocess
import sys

import pytest


@pytest.fixture(scope="session")
def wheels_and_eggs(tmpdir_factory):
    """Build wheels and eggs from test distributions."""
    test_distributions = (
        "complex-dist",
        "simple.dist",
        "headers.dist",
        "commasinfilenames.dist",
        "unicode.dist",
    )

    if sys.platform != "win32":
        # ABI3 extensions don't really work on Windows
        test_distributions += ("abi3extension.dist",)

    pwd = os.path.abspath(os.curdir)
    this_dir = os.path.dirname(__file__)
    build_dir = tmpdir_factory.mktemp("build")
    dist_dir = tmpdir_factory.mktemp("dist")
    for dist in test_distributions:
        os.chdir(os.path.join(this_dir, "testdata", dist))
        subprocess.check_call(
            [
                sys.executable,
                "setup.py",
                "bdist_egg",
                "-b",
                str(build_dir),
                "-d",
                str(dist_dir),
                "bdist_wheel",
                "-b",
                str(build_dir),
                "-d",
                str(dist_dir),
            ]
        )

    os.chdir(pwd)
    return sorted(
        str(fname) for fname in dist_dir.listdir() if fname.ext in (".whl", ".egg")
    )


@pytest.fixture(scope="session")
def wheel_paths(wheels_and_eggs):
    return [fname for fname in wheels_and_eggs if fname.endswith(".whl")]


@pytest.fixture(scope="session")
def egg_paths(wheels_and_eggs):
    return [fname for fname in wheels_and_eggs if fname.endswith(".egg")]



from __future__ import annotations

from setuptools import Extension, setup

setup(
    name="extension.dist",
    version="0.1",
    description="A testing distribution \N{SNOWMAN}",
    ext_modules=[Extension(name="extension", sources=["extension.c"])],
)



from __future__ import annotations

from wheel.metadata import pkginfo_to_metadata


def test_pkginfo_to_metadata(tmpdir):
    expected_metadata = [
        ("Metadata-Version", "2.1"),
        ("Name", "spam"),
        ("Version", "0.1"),
        ("Requires-Dist", "pip @ https://github.com/pypa/pip/archive/1.3.1.zip"),
        ("Requires-Dist", 'pywin32 ; sys_platform=="win32"'),
        ("Requires-Dist", 'foo @ http://host/foo.zip ; sys_platform=="win32"'),
        ("Provides-Extra", "signatures"),
        (
            "Requires-Dist",
            "pyxdg ; (sys_platform!=\"win32\") and extra == 'signatures'",
        ),
        ("Provides-Extra", "empty_extra"),
        ("Provides-Extra", "extra"),
        ("Requires-Dist", "bar @ http://host/bar.zip ; extra == 'extra'"),
        ("Provides-Extra", "faster-signatures"),
        ("Requires-Dist", "ed25519ll ; extra == 'faster-signatures'"),
        ("Provides-Extra", "rest"),
        ("Requires-Dist", "docutils (>=0.8) ; extra == 'rest'"),
        ("Requires-Dist", "keyring ; extra == 'signatures'"),
        ("Requires-Dist", "keyrings.alt ; extra == 'signatures'"),
        ("Provides-Extra", "test"),
        ("Requires-Dist", "pytest (>=3.0.0) ; extra == 'test'"),
        ("Requires-Dist", "pytest-cov ; extra == 'test'"),
    ]

    pkg_info = tmpdir.join("PKG-INFO")
    pkg_info.write(
        """\
Metadata-Version: 0.0
Name: spam
Version: 0.1
Provides-Extra: empty+extra
Provides-Extra: test
Provides-Extra: reST
Provides-Extra: signatures
Provides-Extra: Signatures
Provides-Extra: faster-signatures"""
    )

    egg_info_dir = tmpdir.ensure_dir("test.egg-info")
    egg_info_dir.join("requires.txt").write(
        """\
pip@https://github.com/pypa/pip/archive/1.3.1.zip

[extra]
bar @ http://host/bar.zip

[empty+extra]

[:sys_platform=="win32"]
pywin32
foo @http://host/foo.zip

[faster-signatures]
ed25519ll

[reST]
docutils>=0.8

[signatures]
keyring
keyrings.alt

[Signatures:sys_platform!="win32"]
pyxdg

[test]
pytest>=3.0.0
pytest-cov"""
    )

    message = pkginfo_to_metadata(
        egg_info_path=str(egg_info_dir), pkginfo_path=str(pkg_info)
    )
    assert message.items() == expected_metadata



from __future__ import annotations

import os
from textwrap import dedent
from zipfile import ZipFile

import pytest

from wheel.cli.pack import pack

THISDIR = os.path.dirname(__file__)
TESTWHEEL_NAME = "test-1.0-py2.py3-none-any.whl"
TESTWHEEL_PATH = os.path.join(THISDIR, "..", "testdata", TESTWHEEL_NAME)


@pytest.mark.filterwarnings("error:Duplicate name")
@pytest.mark.parametrize(
    "build_tag_arg, existing_build_tag, filename",
    [
        (None, None, "test-1.0-py2.py3-none-any.whl"),
        ("2b", None, "test-1.0-2b-py2.py3-none-any.whl"),
        (None, "3", "test-1.0-3-py2.py3-none-any.whl"),
        ("", "3", "test-1.0-py2.py3-none-any.whl"),
    ],
    ids=["nobuildnum", "newbuildarg", "oldbuildnum", "erasebuildnum"],
)
def test_pack(tmpdir_factory, tmpdir, build_tag_arg, existing_build_tag, filename):
    unpack_dir = tmpdir_factory.mktemp("wheeldir")
    with ZipFile(TESTWHEEL_PATH) as zf:
        old_record = zf.read("test-1.0.dist-info/RECORD")
        old_record_lines = sorted(
            line.rstrip()
            for line in old_record.split(b"\n")
            if line and not line.startswith(b"test-1.0.dist-info/WHEEL,")
        )
        zf.extractall(str(unpack_dir))

    if existing_build_tag:
        # Add the build number to WHEEL
        wheel_file_path = unpack_dir.join("test-1.0.dist-info").join("WHEEL")
        wheel_file_content = wheel_file_path.read_binary()
        assert b"Build" not in wheel_file_content
        wheel_file_content += b"Build: 3\r\n"
        wheel_file_path.write_binary(wheel_file_content)

    pack(str(unpack_dir), str(tmpdir), build_tag_arg)
    new_wheel_path = tmpdir.join(filename)
    assert new_wheel_path.isfile()

    with ZipFile(str(new_wheel_path)) as zf:
        new_record = zf.read("test-1.0.dist-info/RECORD")
        new_record_lines = sorted(
            line.rstrip()
            for line in new_record.split(b"\n")
            if line and not line.startswith(b"test-1.0.dist-info/WHEEL,")
        )

        new_wheel_file_content = zf.read("test-1.0.dist-info/WHEEL")

    assert new_record_lines == old_record_lines

    expected_build_num = build_tag_arg or existing_build_tag
    expected_wheel_content = dedent(
        """\
        Wheel-Version: 1.0
        Generator: bdist_wheel (0.30.0)
        Root-Is-Purelib: false
        Tag: py2-none-any
        Tag: py3-none-any
    """.replace(
            "\n", "\r\n"
        )
    )
    if expected_build_num:
        expected_wheel_content += "Build: %s\r\n" % expected_build_num

    expected_wheel_content = expected_wheel_content.encode("ascii")
    assert new_wheel_file_content == expected_wheel_content



from __future__ import annotations

import sys
from zipfile import ZIP_DEFLATED, ZipFile

import pytest

from wheel.cli import WheelError
from wheel.wheelfile import WheelFile


@pytest.fixture
def wheel_path(tmpdir):
    return str(tmpdir.join("test-1.0-py2.py3-none-any.whl"))


def test_wheelfile_re(tmpdir):
    # Regression test for #208
    path = tmpdir.join("foo-2-py3-none-any.whl")
    with WheelFile(str(path), "w") as wf:
        assert wf.parsed_filename.group("namever") == "foo-2"


@pytest.mark.parametrize(
    "filename",
    [
        "test.whl",
        "test-1.0.whl",
        "test-1.0-py2.whl",
        "test-1.0-py2-none.whl",
        "test-1.0-py2-none-any",
    ],
)
def test_bad_wheel_filename(filename):
    exc = pytest.raises(WheelError, WheelFile, filename)
    exc.match(f"^Bad wheel filename {filename!r}$")


def test_missing_record(wheel_path):
    with ZipFile(wheel_path, "w") as zf:
        zf.writestr("hello/héllö.py", 'print("Héllö, w0rld!")\n')

    exc = pytest.raises(WheelError, WheelFile, wheel_path)
    exc.match("^Missing test-1.0.dist-info/RECORD file$")


def test_unsupported_hash_algorithm(wheel_path):
    with ZipFile(wheel_path, "w") as zf:
        zf.writestr("hello/héllö.py", 'print("Héllö, w0rld!")\n')
        zf.writestr(
            "test-1.0.dist-info/RECORD",
            "hello/héllö.py,sha000=bv-QV3RciQC2v3zL8Uvhd_arp40J5A9xmyubN34OVwo,25",
        )

    exc = pytest.raises(WheelError, WheelFile, wheel_path)
    exc.match("^Unsupported hash algorithm: sha000$")


@pytest.mark.parametrize(
    "algorithm, digest",
    [("md5", "4J-scNa2qvSgy07rS4at-Q"), ("sha1", "QjCnGu5Qucb6-vir1a6BVptvOA4")],
    ids=["md5", "sha1"],
)
def test_weak_hash_algorithm(wheel_path, algorithm, digest):
    hash_string = f"{algorithm}={digest}"
    with ZipFile(wheel_path, "w") as zf:
        zf.writestr("hello/héllö.py", 'print("Héllö, w0rld!")\n')
        zf.writestr("test-1.0.dist-info/RECORD", f"hello/héllö.py,{hash_string},25")

    exc = pytest.raises(WheelError, WheelFile, wheel_path)
    exc.match(rf"^Weak hash algorithm \({algorithm}\) is not permitted by PEP 427$")


@pytest.mark.parametrize(
    "algorithm, digest",
    [
        ("sha256", "bv-QV3RciQC2v3zL8Uvhd_arp40J5A9xmyubN34OVwo"),
        ("sha384", "cDXriAy_7i02kBeDkN0m2RIDz85w6pwuHkt2PZ4VmT2PQc1TZs8Ebvf6eKDFcD_S"),
        (
            "sha512",
            "kdX9CQlwNt4FfOpOKO_X0pn_v1opQuksE40SrWtMyP1NqooWVWpzCE3myZTfpy8g2azZON_"
            "iLNpWVxTwuDWqBQ",
        ),
    ],
    ids=["sha256", "sha384", "sha512"],
)
def test_testzip(wheel_path, algorithm, digest):
    hash_string = f"{algorithm}={digest}"
    with ZipFile(wheel_path, "w") as zf:
        zf.writestr("hello/héllö.py", 'print("Héllö, world!")\n')
        zf.writestr("test-1.0.dist-info/RECORD", f"hello/héllö.py,{hash_string},25")

    with WheelFile(wheel_path) as wf:
        wf.testzip()


def test_testzip_missing_hash(wheel_path):
    with ZipFile(wheel_path, "w") as zf:
        zf.writestr("hello/héllö.py", 'print("Héllö, world!")\n')
        zf.writestr("test-1.0.dist-info/RECORD", "")

    with WheelFile(wheel_path) as wf:
        exc = pytest.raises(WheelError, wf.testzip)
        exc.match("^No hash found for file 'hello/héllö.py'$")


def test_testzip_bad_hash(wheel_path):
    with ZipFile(wheel_path, "w") as zf:
        zf.writestr("hello/héllö.py", 'print("Héllö, w0rld!")\n')
        zf.writestr(
            "test-1.0.dist-info/RECORD",
            "hello/héllö.py,sha256=bv-QV3RciQC2v3zL8Uvhd_arp40J5A9xmyubN34OVwo,25",
        )

    with WheelFile(wheel_path) as wf:
        exc = pytest.raises(WheelError, wf.testzip)
        exc.match("^Hash mismatch for file 'hello/héllö.py'$")


def test_write_str(wheel_path):
    with WheelFile(wheel_path, "w") as wf:
        wf.writestr("hello/héllö.py", 'print("Héllö, world!")\n')
        wf.writestr("hello/h,ll,.py", 'print("Héllö, world!")\n')

    with ZipFile(wheel_path, "r") as zf:
        infolist = zf.infolist()
        assert len(infolist) == 3
        assert infolist[0].filename == "hello/héllö.py"
        assert infolist[0].file_size == 25
        assert infolist[1].filename == "hello/h,ll,.py"
        assert infolist[1].file_size == 25
        assert infolist[2].filename == "test-1.0.dist-info/RECORD"

        record = zf.read("test-1.0.dist-info/RECORD")
        assert record.decode("utf-8") == (
            "hello/héllö.py,sha256=bv-QV3RciQC2v3zL8Uvhd_arp40J5A9xmyubN34OVwo,25\n"
            '"hello/h,ll,.py",sha256=bv-QV3RciQC2v3zL8Uvhd_arp40J5A9xmyubN34OVwo,25\n'
            "test-1.0.dist-info/RECORD,,\n"
        )


def test_timestamp(tmpdir_factory, wheel_path, monkeypatch):
    # An environment variable can be used to influence the timestamp on
    # TarInfo objects inside the zip.  See issue #143.
    build_dir = tmpdir_factory.mktemp("build")
    for filename in ("one", "two", "three"):
        build_dir.join(filename).write(filename + "\n")

    # The earliest date representable in TarInfos, 1980-01-01
    monkeypatch.setenv("SOURCE_DATE_EPOCH", "315576060")

    with WheelFile(wheel_path, "w") as wf:
        wf.write_files(str(build_dir))

    with ZipFile(wheel_path, "r") as zf:
        for info in zf.infolist():
            assert info.date_time[:3] == (1980, 1, 1)
            assert info.compress_type == ZIP_DEFLATED


@pytest.mark.skipif(
    sys.platform == "win32", reason="Windows does not support UNIX-like permissions"
)
def test_attributes(tmpdir_factory, wheel_path):
    # With the change from ZipFile.write() to .writestr(), we need to manually
    # set member attributes.
    build_dir = tmpdir_factory.mktemp("build")
    files = (("foo", 0o644), ("bar", 0o755))
    for filename, mode in files:
        path = build_dir.join(filename)
        path.write(filename + "\n")
        path.chmod(mode)

    with WheelFile(wheel_path, "w") as wf:
        wf.write_files(str(build_dir))

    with ZipFile(wheel_path, "r") as zf:
        for filename, mode in files:
            info = zf.getinfo(filename)
            assert info.external_attr == (mode | 0o100000) << 16
            assert info.compress_type == ZIP_DEFLATED

        info = zf.getinfo("test-1.0.dist-info/RECORD")
        permissions = (info.external_attr >> 16) & 0o777
        assert permissions == 0o664



from __future__ import annotations

import os
import sys
import sysconfig

from wheel.bdist_wheel import get_platform
from wheel.macosx_libfile import extract_macosx_min_system_version


def test_read_from_dylib():
    dirname = os.path.dirname(__file__)
    dylib_dir = os.path.join(dirname, "testdata", "macosx_minimal_system_version")
    versions = [
        ("test_lib_10_6_fat.dylib", "10.6.0"),
        ("test_lib_10_10_fat.dylib", "10.10.0"),
        ("test_lib_10_14_fat.dylib", "10.14.0"),
        ("test_lib_10_6.dylib", "10.6.0"),
        ("test_lib_10_10.dylib", "10.10.0"),
        ("test_lib_10_14.dylib", "10.14.0"),
        ("test_lib_10_6_386.dylib", "10.6.0"),
        ("test_lib_10_10_386.dylib", "10.10.0"),
        ("test_lib_10_14_386.dylib", "10.14.0"),
        ("test_lib_multiple_fat.dylib", "10.14.0"),
        ("test_lib_10_10_10.dylib", "10.10.10"),
        ("test_lib_11.dylib", "11.0.0"),
        ("test_lib_10_9_universal2.dylib", "10.9.0"),
    ]
    for file_name, ver in versions:
        extracted = extract_macosx_min_system_version(
            os.path.join(dylib_dir, file_name)
        )
        str_ver = ".".join([str(x) for x in extracted])
        assert str_ver == ver
    assert (
        extract_macosx_min_system_version(os.path.join(dylib_dir, "test_lib.c")) is None
    )
    assert (
        extract_macosx_min_system_version(os.path.join(dylib_dir, "libb.dylib")) is None
    )


def return_factory(return_val):
    def fun(*args, **kwargs):
        return return_val

    return fun


class TestGetPlatformMacosx:
    def test_simple(self, monkeypatch):
        dirname = os.path.dirname(__file__)
        dylib_dir = os.path.join(dirname, "testdata", "macosx_minimal_system_version")
        monkeypatch.setattr(
            sysconfig, "get_platform", return_factory("macosx-11.0-x86_64")
        )
        assert get_platform(dylib_dir) == "macosx_11_0_x86_64"

    def test_version_bump(self, monkeypatch, capsys):
        dirname = os.path.dirname(__file__)
        dylib_dir = os.path.join(dirname, "testdata", "macosx_minimal_system_version")
        monkeypatch.setattr(
            sysconfig, "get_platform", return_factory("macosx-10.9-x86_64")
        )
        assert get_platform(dylib_dir) == "macosx_11_0_x86_64"
        captured = capsys.readouterr()
        assert "[WARNING] This wheel needs a higher macOS version than" in captured.err

    def test_information_about_problematic_files_python_version(
        self, monkeypatch, capsys
    ):
        dirname = os.path.dirname(__file__)
        dylib_dir = os.path.join(dirname, "testdata", "macosx_minimal_system_version")
        monkeypatch.setattr(
            sysconfig, "get_platform", return_factory("macosx-10.9-x86_64")
        )
        monkeypatch.setattr(
            os,
            "walk",
            return_factory(
                [(dylib_dir, [], ["test_lib_10_6.dylib", "test_lib_10_10_fat.dylib"])]
            ),
        )
        assert get_platform(dylib_dir) == "macosx_10_10_x86_64"
        captured = capsys.readouterr()
        assert "[WARNING] This wheel needs a higher macOS version than" in captured.err
        assert (
            "the version your Python interpreter is compiled against." in captured.err
        )
        assert "test_lib_10_10_fat.dylib" in captured.err

    def test_information_about_problematic_files_env_variable(
        self, monkeypatch, capsys
    ):
        dirname = os.path.dirname(__file__)
        dylib_dir = os.path.join(dirname, "testdata", "macosx_minimal_system_version")
        monkeypatch.setattr(
            sysconfig, "get_platform", return_factory("macosx-10.9-x86_64")
        )
        monkeypatch.setenv("MACOSX_DEPLOYMENT_TARGET", "10.8")
        monkeypatch.setattr(
            os,
            "walk",
            return_factory(
                [(dylib_dir, [], ["test_lib_10_6.dylib", "test_lib_10_10_fat.dylib"])]
            ),
        )
        assert get_platform(dylib_dir) == "macosx_10_10_x86_64"
        captured = capsys.readouterr()
        assert "[WARNING] This wheel needs a higher macOS version than" in captured.err
        assert "is set in MACOSX_DEPLOYMENT_TARGET variable." in captured.err
        assert "test_lib_10_10_fat.dylib" in captured.err

    def test_bump_platform_tag_by_env_variable(self, monkeypatch, capsys):
        dirname = os.path.dirname(__file__)
        dylib_dir = os.path.join(dirname, "testdata", "macosx_minimal_system_version")
        monkeypatch.setattr(
            sysconfig, "get_platform", return_factory("macosx-10.9-x86_64")
        )
        monkeypatch.setattr(
            os,
            "walk",
            return_factory(
                [(dylib_dir, [], ["test_lib_10_6.dylib", "test_lib_10_6_fat.dylib"])]
            ),
        )
        assert get_platform(dylib_dir) == "macosx_10_9_x86_64"
        monkeypatch.setenv("MACOSX_DEPLOYMENT_TARGET", "10.10")
        assert get_platform(dylib_dir) == "macosx_10_10_x86_64"
        captured = capsys.readouterr()
        assert captured.err == ""

    def test_bugfix_release_platform_tag(self, monkeypatch, capsys):
        dirname = os.path.dirname(__file__)
        dylib_dir = os.path.join(dirname, "testdata", "macosx_minimal_system_version")
        monkeypatch.setattr(
            sysconfig, "get_platform", return_factory("macosx-10.9-x86_64")
        )
        monkeypatch.setattr(
            os,
            "walk",
            return_factory(
                [
                    (
                        dylib_dir,
                        [],
                        [
                            "test_lib_10_6.dylib",
                            "test_lib_10_6_fat.dylib",
                            "test_lib_10_10_10.dylib",
                        ],
                    )
                ]
            ),
        )
        assert get_platform(dylib_dir) == "macosx_10_10_x86_64"
        captured = capsys.readouterr()
        assert "This wheel needs a higher macOS version than" in captured.err
        monkeypatch.setenv("MACOSX_DEPLOYMENT_TARGET", "10.9")
        assert get_platform(dylib_dir) == "macosx_10_10_x86_64"
        captured = capsys.readouterr()
        assert "This wheel needs a higher macOS version than" in captured.err

    def test_warning_on_to_low_env_variable(self, monkeypatch, capsys):
        dirname = os.path.dirname(__file__)
        dylib_dir = os.path.join(dirname, "testdata", "macosx_minimal_system_version")
        monkeypatch.setattr(
            sysconfig, "get_platform", return_factory("macosx-10.9-x86_64")
        )
        monkeypatch.setenv("MACOSX_DEPLOYMENT_TARGET", "10.8")
        monkeypatch.setattr(
            os,
            "walk",
            return_factory(
                [(dylib_dir, [], ["test_lib_10_6.dylib", "test_lib_10_6_fat.dylib"])]
            ),
        )
        assert get_platform(dylib_dir) == "macosx_10_9_x86_64"
        captured = capsys.readouterr()
        assert (
            "MACOSX_DEPLOYMENT_TARGET is set to a lower value (10.8) than the"
            in captured.err
        )

    def test_get_platform_bigsur_env(self, monkeypatch):
        dirname = os.path.dirname(__file__)
        dylib_dir = os.path.join(dirname, "testdata", "macosx_minimal_system_version")
        monkeypatch.setattr(
            sysconfig, "get_platform", return_factory("macosx-10.9-x86_64")
        )
        monkeypatch.setenv("MACOSX_DEPLOYMENT_TARGET", "11")
        monkeypatch.setattr(
            os,
            "walk",
            return_factory(
                [(dylib_dir, [], ["test_lib_10_6.dylib", "test_lib_10_10_fat.dylib"])]
            ),
        )
        assert get_platform(dylib_dir) == "macosx_11_0_x86_64"

    def test_get_platform_bigsur_platform(self, monkeypatch):
        dirname = os.path.dirname(__file__)
        dylib_dir = os.path.join(dirname, "testdata", "macosx_minimal_system_version")
        monkeypatch.setattr(
            sysconfig, "get_platform", return_factory("macosx-11-x86_64")
        )
        monkeypatch.setattr(
            os,
            "walk",
            return_factory(
                [(dylib_dir, [], ["test_lib_10_6.dylib", "test_lib_10_10_fat.dylib"])]
            ),
        )
        assert get_platform(dylib_dir) == "macosx_11_0_x86_64"


def test_get_platform_linux(monkeypatch):
    monkeypatch.setattr(sysconfig, "get_platform", return_factory("linux-x86_64"))
    monkeypatch.setattr(sys, "maxsize", 2147483647)
    assert get_platform(None) == "linux_i686"



from __future__ import annotations

import os.path
import re

from wheel.cli.convert import convert, egg_info_re
from wheel.wheelfile import WHEEL_INFO_RE


def test_egg_re():
    """Make sure egg_info_re matches."""
    egg_names_path = os.path.join(os.path.dirname(__file__), "eggnames.txt")
    with open(egg_names_path) as egg_names:
        for line in egg_names:
            line = line.strip()
            if line:
                assert egg_info_re.match(line), line


def test_convert_egg(egg_paths, tmpdir):
    convert(egg_paths, str(tmpdir), verbose=False)
    wheel_names = [path.basename for path in tmpdir.listdir()]
    assert len(wheel_names) == len(egg_paths)
    assert all(WHEEL_INFO_RE.match(filename) for filename in wheel_names)
    assert all(
        re.match(r"^[\w\d.]+-\d\.\d-\w+\d+-[\w\d]+-[\w\d]+\.whl$", fname)
        for fname in wheel_names
    )



from __future__ import annotations

from wheel.cli.unpack import unpack


def test_unpack(wheel_paths, tmpdir):
    """
    Make sure 'wheel unpack' works.
    This also verifies the integrity of our testing wheel files.
    """
    for wheel_path in wheel_paths:
        unpack(wheel_path, str(tmpdir))



from __future__ import annotations

from setuptools import setup

setup(
    name="simple.dist",
    version="0.1",
    description="A testing distribution \N{SNOWMAN}",
    packages=["simpledist"],
    extras_require={"voting": ["beaglevote"]},
)
